<?php //:noTabs=false:folding=explicit:tabSize=8:

/**
 *@(#)Form.php - a dynamic html form generator
 *
 * @author	Daniel Brandauer
 * @version	0.1
 * @modified	2004.09.29
 */
include_once 'lib/FormPainter.php';
include_once 'lib/DefaultFormPainter.php';
include_once 'lib/Util.php';
include_once 'lib/FormField.php';

/**
 * Form
 * An input form abstraction. Makes it possable to create form defenitions
 * which can be used for both presentation and processing.
 */
class Form
{
	/**
	 * $fields
	 * An array of FormField objects containing all of the form's elements
	 */
	public $fields = array();
	
	/**
	 * createField()
	 * Creates a new FormField object and adds it to the internal field
	 * array.
	 *
	 * @param	$text	The display text or field caption
	 * @param	$id	The form element id or name for processing
	 * @param	$type	The form element type such as text, email, etc.
	 * @return	The newly created FormField object
	 */
	public function createField($text, $id, $type='text')
	{
		$fld = new FormField($text, $id, $type);
		
		array_push($this->fields, &$fld);
		return $fld;
	}
	
	/**
	 * paint()
	 * Generates the form's output code for display to the end user. Uses
	 * the supplied painter object or a DefaultFormPainter object if nothing
	 * is supplied.
	 *
	 * @param	$painter	The FormPainter implimentation to use
	 * @return	A string containing the output code
	 */
	function paint(&$painter = null)
	{
		if($painter == null) {
			$painter = new DefaultFormPainter();
		}
		
		$buffer = "";
		
		$buffer .= $painter->sketch();
		
		foreach($this->fields as $field) {
			$buffer .= $painter->paint(&$field);
		}
		
		$buffer .= $painter->gloss();
		
		return $buffer;
	}
	
	/**
	 * validate()
	 * Validates incoming form data.
	 *
	 * @param	$data	The incoming form data array
	 * @param	$form	The form object to reference these data by
	 * @return	true if there were no problems detected, false otherwise
	 */
	public static function validate($data, $form)
	{
		$i = 0;
		
		for($i = 0; $i < count($form->fields); $i++) {
			$cfield =& $form->fields[$i];
			$cdatum = $data[$cfield->id];
			
			if($cfield->type == 'submit') {
				break;
			}
			
			if($cdatum == '') {
				return false;
			}
			
			if($cfield->type == 'email') {
				if(!ereg('^\+?[a-z0-9](([-+.]|[_]+)?[a-z0-9]+)*@([a-z0-9]+(\.|\-))+[a-z]{2,6}$', $cdatum)) {
					return false;
				}
			}
		}
		
		return true;
	}
	
	/**
	 * loadFormItems()
	 * Creates an array from incoming data by extracting only the items
	 * which belong to the specified form.
	 *
	 * @param	$data	Raw input
	 * @param	$form	Form object to filter by
	 * @return	Array of form elements
	 */
	public static function loadFormItems($data, $form)
	{
		$i = 0;
		$buffer = array();
		
		for($i = 0; $i < count($form->fields); $i++) {
			$cfield =& $form->fields[$i];
			$cdatum = $data[$cfield->id];
			
			$buffer[$cfield->id] = $cdatum;
		}
		
		return $buffer;
	}
}
?>

