<?php
include_once 'Data.php';
include_once 'Page.php';
include_once 'Config.php';
include_once 'Module.php';

class PageManager
{
	private $data;
	private static $strings = array();
	
	function __construct()
	{
		$this->data = new Data();
	}
	
	/**
	 * Adds a new page to the database.
	 *
	 *@param $id		language neutral identifier
	 *@param $title		the display title for the page
	 *@param $category	processing category (for sidebar, etc.)
	 *@param $content	the important part :)
	 *@param $language	natural language of content
	 */
	public function createPage($id, $title, $category, $content, $language)
	{
		$query = "insert into pages (page_id,page_title,category_name,language,page_content)";
		$query .= " values ('$id','$title','$category','$language','$content')";
		
		$this->data->exec($query);
	}
	
	/**
	 * Adds a new module defenition to the database.
	 * It is possible to register a module for both a page and a category
	 * but this could lead to problems.
	 *
	 *@param $pageId	page for which this module should be registered
	 *@param $category	category for which this module should be registered
	 *@param $type		module type (header, footer, side[top|bottom])
	 *@param $replaceTemplate	if true, template is removed, else
	 *			module use assumed to compliment template
	 *			1 = true
	 *			0 = false
	 */
	public function createModule($pageId, $category, $name, $type, $replaceTemplate=1)
	{
		$query = "insert into modules (page_id,category_name,module_name,module_type,replace_template)";
		$query .= " values ('$pageId','$category','$name','$type',$replaceTemplate)";
		
		$this->data->exec($query);
	}
	
	public function createNewsItem($date, $title, $content, $language)
	{
		$query = "insert into news (news_date,news_title,news_content,language)";
		$query .= " values ($date,'$title','$content','$language')";
		
		$this->data->exec($query);
	}
	
	public function getModules($for)
	{
		$modules = array();
		$i = 0;
		
		$query = "select * from modules where page_id='$for' or category_name='$for'";
		
		$this->data->query($query);
		
		while($this->data->hasMoreRows()) {
			$row = $this->data->fetchAssoc();
			$modules[$i] = new Module();
			$modules[$i]->page = $row['page_id'];
			$modules[$i]->category = $row['category_name'];
			$modules[$i]->type = $row['module_type'];
			$modules[$i]->name = $row['module_name'];
			if($row['replace_template'] > 0) {
				$modules[$i]->replaceTemplate = true;
			} else {
				$modules[$i]->replaceTemplate = false;
			}
			$i++;
		}
		
		return $modules;
	}
	
	public function getPageId($title)
	{
		$query = "select page_id from pages where page_title='$title'";
		
		$this->data->query($query);
		$row = $this->data->fetchAssoc();
		
		return ($row['page_id']);
	}
	
	public function pageIdExists($id)
	{
		$query = "select page_id from pages where page_id='$id'";
		
		$this->data->query($query);
		
		return $this->data->hasMoreRows();
	}
	
	public function getPageTitle($id)
	{
		$query = "select page_title from pages where page_id='$id'";
		
		$this->data->query($query);
		$row = $this->data->fetchAssoc();
		
		return ($row['page_id']);
	}
	
	public function loadPage($id, $lang)
	{
		$page = new Page();
		$defaultLanguage = Config::getProperty('default language');
		
		$query = "select page_title,page_content,category_name from pages where page_id='$id' and language='$lang'";
		$result = $this->data->query($query);
		$row = $this->data->fetchAssoc();
		
		$page->id = $id;
		$page->title = $row['page_title'];
		$page->content = $row['page_content'];
		$page->category = $row['category_name'];
		$page->language = $lang;
		
		if($page->content == '' && $page->title == '' && $lang != $defaultLanguage) {
			$mypage =& $this->loadPage($id, $defaultLangauge);
			$strings = $this->getStrings($lang);
			$mypage->headnote =$strings['not_available_in'];
			
			return $mypage;
		}
		
		return $page;
	}
	
	public function loadTemplates(&$page)
	{
		$query = "select * from categories where category_name='".$page->category."'";
		$this->data->query($query);
		$cat = $this->data->fetchAssoc();
		
		$list = array('left_top','left_bottom','right_top','right_bottom','header');
		$templates = array();
		
		foreach($list as $item) {
			if($cat[$item.'_template'] != '') {
				$templates[$item] = $cat[$item.'_template'];
			} else {
				$templates[$item] = "default_$item.tpl";
			}
		}
		
		$page->templates = $templates;
		
		return $page->templates;
	}
	
	public function loadModules(&$page)
	{
		$page->modules = $this->getModules($page->id, 'page');
		return $page->modules;
	}
	
	public function getCategoryImage($category)
	{
		$query = "select category_image from categories where category_name='$category'";
		$this->data->query($query);
		$cat = $this->data->fetchAssoc();
		
		return $cat['category_image'];
	}
	
	public function getStrings($language)
	{
		if(empty(self::$strings)) {
			$strings = array();
			$query = "select string_id,string from strings where language='$language'";
			$this->data->query($query);
			
			while($this->data->hasMoreRows()) {
				$row = $this->data->fetchAssoc();
				$strings[$row['string_id']] = $row['string'];
			}
			
			return $strings;
		} else {
			return self::$strings;
		}
	}
	
	public function getSupportedLanguages()
	{
		$languages = array();
		$query = "select distinct language from pages";
		$this->data->query($query);
		
		while($this->data->hasMoreRows()) {
			$row = $this->data->fetchAssoc();
			$languages[] = $row['language'];
		}
		
		return $languages;
	}
	
	public function isSupportedLanguage($language)
	{
		$languages = $this->getSupportedLanguages();
		
		foreach($languages as $l) {
			if($l == $language) {
				return true;
			}
		}
		
		return false;
	}
}
?>
