<?php
class Search
{
	/**
	 * Parses the query as recieved from the client and returns an SQL query
	 * Accepts the following conventions:
	 *    +word: page contains all words
	 *    -word: page does not contain following word
	 *    word or word2: page contains either word or word2
	 *    word*: wildcard search
	 *    word, and word2: page contains phrase word word2
	 */
	public static function parseQueryString($queryString)
	{
		// the possible parts of a query string
		$parts = array(
			'literals'	=>	'/[\w\*]+, and [\w\*]+/',
			'or'		=>	'/[\w\*]+\s+or\s+[\w\*]+/',
			'and'		=>	'/\+[\w\*]+/',
			'not'		=>	'/\-\w+/',
			'remainder'	=>	'/[\w\*]+/'
			);
		
		// patterns to remove processing data from extracted query
		// string components
		$clean = array(
			'literals'	=>	'/,\s+and\s+/',
			'or'		=>	'/\s+or\s+/',
			'and'		=>	'/\+/',
			'not'		=>	'/\-/',
			'remainder'	=>	'/\w/'
			);
		
		$string = $queryString;
		
		// if the query string is blank, don't bother to try processing
		if($string == '') { return false; }
		
		// this array holds all of the extracted query string components
		$test = array();
		
		// the string buffer that will eventually be returned
		$query = '';
		
		// initialize query
		$query = 'select * from pages where';
		$firstAddition = true;
		
		// extract each query type then remove it for clarity
		foreach($parts as $name => $pattern) {
			preg_match_all($pattern, $string, $test[$name]);
			$string = preg_replace($pattern, '', $string);
		}
		
		// begin where claus
		$query .= ' (';
		
		
		// process query parts
		foreach($test as $name => $content) {
			if(count($content[0]) > 0) {
				if(!$firstAddition) {
					$query .= ' and';
				} else {
					$firstAddition = false;
				}
				$query .= ' (';
				foreach($content[0] as $item) {
					$cleaned = preg_replace($clean[$name], ' ', $item);
					if($name != 'not') {
						$query .= " (page_content like '*$cleaned*')";
					} else {
						$query .= " (page_content not like '*$cleaned*')";
					}
				}
				$query .= ' )';
			}
		}
		
		// end where claus
		$query .= ' )';
		
		return $query;
	}
}
?>
